@@ -1,5 +1,8 @@
 # -*- coding: utf-8 -*-
 
+'''
+Module Init
+'''
 
-__version__ = "0.1"
+__version__ = "0.2"
 __license__ = "BSD"
